// Code generated by "stringer -type=EventType"; DO NOT EDIT.

package tui

import "strconv"

func _() {
	// An "invalid array index" compiler error signifies that the constant values have changed.
	// Re-run the stringer command to generate them again.
	var x [1]struct{}
	_ = x[Rune-0]
	_ = x[CtrlA-1]
	_ = x[CtrlB-2]
	_ = x[CtrlC-3]
	_ = x[CtrlD-4]
	_ = x[CtrlE-5]
	_ = x[CtrlF-6]
	_ = x[CtrlG-7]
	_ = x[CtrlBackspace-8]
	_ = x[Tab-9]
	_ = x[CtrlJ-10]
	_ = x[CtrlK-11]
	_ = x[CtrlL-12]
	_ = x[Enter-13]
	_ = x[CtrlN-14]
	_ = x[CtrlO-15]
	_ = x[CtrlP-16]
	_ = x[CtrlQ-17]
	_ = x[CtrlR-18]
	_ = x[CtrlS-19]
	_ = x[CtrlT-20]
	_ = x[CtrlU-21]
	_ = x[CtrlV-22]
	_ = x[CtrlW-23]
	_ = x[CtrlX-24]
	_ = x[CtrlY-25]
	_ = x[CtrlZ-26]
	_ = x[Esc-27]
	_ = x[CtrlSpace-28]
	_ = x[CtrlBackSlash-29]
	_ = x[CtrlRightBracket-30]
	_ = x[CtrlCaret-31]
	_ = x[CtrlSlash-32]
	_ = x[ShiftTab-33]
	_ = x[Backspace-34]
	_ = x[Delete-35]
	_ = x[PageUp-36]
	_ = x[PageDown-37]
	_ = x[Up-38]
	_ = x[Down-39]
	_ = x[Left-40]
	_ = x[Right-41]
	_ = x[Home-42]
	_ = x[End-43]
	_ = x[Insert-44]
	_ = x[ShiftUp-45]
	_ = x[ShiftDown-46]
	_ = x[ShiftLeft-47]
	_ = x[ShiftRight-48]
	_ = x[ShiftDelete-49]
	_ = x[ShiftHome-50]
	_ = x[ShiftEnd-51]
	_ = x[ShiftPageUp-52]
	_ = x[ShiftPageDown-53]
	_ = x[F1-54]
	_ = x[F2-55]
	_ = x[F3-56]
	_ = x[F4-57]
	_ = x[F5-58]
	_ = x[F6-59]
	_ = x[F7-60]
	_ = x[F8-61]
	_ = x[F9-62]
	_ = x[F10-63]
	_ = x[F11-64]
	_ = x[F12-65]
	_ = x[AltBackspace-66]
	_ = x[AltUp-67]
	_ = x[AltDown-68]
	_ = x[AltLeft-69]
	_ = x[AltRight-70]
	_ = x[AltDelete-71]
	_ = x[AltHome-72]
	_ = x[AltEnd-73]
	_ = x[AltPageUp-74]
	_ = x[AltPageDown-75]
	_ = x[AltShiftUp-76]
	_ = x[AltShiftDown-77]
	_ = x[AltShiftLeft-78]
	_ = x[AltShiftRight-79]
	_ = x[AltShiftDelete-80]
	_ = x[AltShiftHome-81]
	_ = x[AltShiftEnd-82]
	_ = x[AltShiftPageUp-83]
	_ = x[AltShiftPageDown-84]
	_ = x[CtrlUp-85]
	_ = x[CtrlDown-86]
	_ = x[CtrlLeft-87]
	_ = x[CtrlRight-88]
	_ = x[CtrlHome-89]
	_ = x[CtrlEnd-90]
	_ = x[CtrlDelete-91]
	_ = x[CtrlPageUp-92]
	_ = x[CtrlPageDown-93]
	_ = x[Alt-94]
	_ = x[CtrlAlt-95]
	_ = x[CtrlAltUp-96]
	_ = x[CtrlAltDown-97]
	_ = x[CtrlAltLeft-98]
	_ = x[CtrlAltRight-99]
	_ = x[CtrlAltHome-100]
	_ = x[CtrlAltEnd-101]
	_ = x[CtrlAltBackspace-102]
	_ = x[CtrlAltDelete-103]
	_ = x[CtrlAltPageUp-104]
	_ = x[CtrlAltPageDown-105]
	_ = x[CtrlShiftUp-106]
	_ = x[CtrlShiftDown-107]
	_ = x[CtrlShiftLeft-108]
	_ = x[CtrlShiftRight-109]
	_ = x[CtrlShiftHome-110]
	_ = x[CtrlShiftEnd-111]
	_ = x[CtrlShiftDelete-112]
	_ = x[CtrlShiftPageUp-113]
	_ = x[CtrlShiftPageDown-114]
	_ = x[CtrlAltShiftUp-115]
	_ = x[CtrlAltShiftDown-116]
	_ = x[CtrlAltShiftLeft-117]
	_ = x[CtrlAltShiftRight-118]
	_ = x[CtrlAltShiftHome-119]
	_ = x[CtrlAltShiftEnd-120]
	_ = x[CtrlAltShiftDelete-121]
	_ = x[CtrlAltShiftPageUp-122]
	_ = x[CtrlAltShiftPageDown-123]
	_ = x[Invalid-124]
	_ = x[Fatal-125]
	_ = x[BracketedPasteBegin-126]
	_ = x[BracketedPasteEnd-127]
	_ = x[Mouse-128]
	_ = x[DoubleClick-129]
	_ = x[LeftClick-130]
	_ = x[RightClick-131]
	_ = x[SLeftClick-132]
	_ = x[SRightClick-133]
	_ = x[ScrollUp-134]
	_ = x[ScrollDown-135]
	_ = x[SScrollUp-136]
	_ = x[SScrollDown-137]
	_ = x[PreviewScrollUp-138]
	_ = x[PreviewScrollDown-139]
	_ = x[Resize-140]
	_ = x[Change-141]
	_ = x[BackwardEOF-142]
	_ = x[Start-143]
	_ = x[Load-144]
	_ = x[Focus-145]
	_ = x[One-146]
	_ = x[Zero-147]
	_ = x[Result-148]
	_ = x[Jump-149]
	_ = x[JumpCancel-150]
	_ = x[ClickHeader-151]
	_ = x[ClickFooter-152]
	_ = x[Multi-153]
}

const _EventType_name = "RuneCtrlACtrlBCtrlCCtrlDCtrlECtrlFCtrlGCtrlBackspaceTabCtrlJCtrlKCtrlLEnterCtrlNCtrlOCtrlPCtrlQCtrlRCtrlSCtrlTCtrlUCtrlVCtrlWCtrlXCtrlYCtrlZEscCtrlSpaceCtrlBackSlashCtrlRightBracketCtrlCaretCtrlSlashShiftTabBackspaceDeletePageUpPageDownUpDownLeftRightHomeEndInsertShiftUpShiftDownShiftLeftShiftRightShiftDeleteShiftHomeShiftEndShiftPageUpShiftPageDownF1F2F3F4F5F6F7F8F9F10F11F12AltBackspaceAltUpAltDownAltLeftAltRightAltDeleteAltHomeAltEndAltPageUpAltPageDownAltShiftUpAltShiftDownAltShiftLeftAltShiftRightAltShiftDeleteAltShiftHomeAltShiftEndAltShiftPageUpAltShiftPageDownCtrlUpCtrlDownCtrlLeftCtrlRightCtrlHomeCtrlEndCtrlDeleteCtrlPageUpCtrlPageDownAltCtrlAltCtrlAltUpCtrlAltDownCtrlAltLeftCtrlAltRightCtrlAltHomeCtrlAltEndCtrlAltBackspaceCtrlAltDeleteCtrlAltPageUpCtrlAltPageDownCtrlShiftUpCtrlShiftDownCtrlShiftLeftCtrlShiftRightCtrlShiftHomeCtrlShiftEndCtrlShiftDeleteCtrlShiftPageUpCtrlShiftPageDownCtrlAltShiftUpCtrlAltShiftDownCtrlAltShiftLeftCtrlAltShiftRightCtrlAltShiftHomeCtrlAltShiftEndCtrlAltShiftDeleteCtrlAltShiftPageUpCtrlAltShiftPageDownInvalidFatalBracketedPasteBeginBracketedPasteEndMouseDoubleClickLeftClickRightClickSLeftClickSRightClickScrollUpScrollDownSScrollUpSScrollDownPreviewScrollUpPreviewScrollDownResizeChangeBackwardEOFStartLoadFocusOneZeroResultJumpJumpCancelClickHeaderClickFooterMulti"

var _EventType_index = [...]uint16{0, 4, 9, 14, 19, 24, 29, 34, 39, 52, 55, 60, 65, 70, 75, 80, 85, 90, 95, 100, 105, 110, 115, 120, 125, 130, 135, 140, 143, 152, 165, 181, 190, 199, 207, 216, 222, 228, 236, 238, 242, 246, 251, 255, 258, 264, 271, 280, 289, 299, 310, 319, 327, 338, 351, 353, 355, 357, 359, 361, 363, 365, 367, 369, 372, 375, 378, 390, 395, 402, 409, 417, 426, 433, 439, 448, 459, 469, 481, 493, 506, 520, 532, 543, 557, 573, 579, 587, 595, 604, 612, 619, 629, 639, 651, 654, 661, 670, 681, 692, 704, 715, 725, 741, 754, 767, 782, 793, 806, 819, 833, 846, 858, 873, 888, 905, 919, 935, 951, 968, 984, 999, 1017, 1035, 1055, 1062, 1067, 1086, 1103, 1108, 1119, 1128, 1138, 1148, 1159, 1167, 1177, 1186, 1197, 1212, 1229, 1235, 1241, 1252, 1257, 1261, 1266, 1269, 1273, 1279, 1283, 1293, 1304, 1315, 1320}

func (i EventType) String() string {
	if i < 0 || i >= EventType(len(_EventType_index)-1) {
		return "EventType(" + strconv.FormatInt(int64(i), 10) + ")"
	}
	return _EventType_name[_EventType_index[i]:_EventType_index[i+1]]
}
