// Code generated by "stringer -type=actionType"; DO NOT EDIT.

package fzf

import "strconv"

func _() {
	// An "invalid array index" compiler error signifies that the constant values have changed.
	// Re-run the stringer command to generate them again.
	var x [1]struct{}
	_ = x[actIgnore-0]
	_ = x[actStart-1]
	_ = x[actClick-2]
	_ = x[actInvalid-3]
	_ = x[actBracketedPasteBegin-4]
	_ = x[actBracketedPasteEnd-5]
	_ = x[actChar-6]
	_ = x[actMouse-7]
	_ = x[actBeginningOfLine-8]
	_ = x[actAbort-9]
	_ = x[actAccept-10]
	_ = x[actAcceptNonEmpty-11]
	_ = x[actAcceptOrPrintQuery-12]
	_ = x[actBackwardChar-13]
	_ = x[actBackwardDeleteChar-14]
	_ = x[actBackwardDeleteCharEof-15]
	_ = x[actBackwardWord-16]
	_ = x[actBackwardSubWord-17]
	_ = x[actCancel-18]
	_ = x[actChangeBorderLabel-19]
	_ = x[actChangeGhost-20]
	_ = x[actChangeHeader-21]
	_ = x[actChangeFooter-22]
	_ = x[actChangeHeaderLabel-23]
	_ = x[actChangeFooterLabel-24]
	_ = x[actChangeInputLabel-25]
	_ = x[actChangeListLabel-26]
	_ = x[actChangeMulti-27]
	_ = x[actChangeNth-28]
	_ = x[actChangePointer-29]
	_ = x[actChangePreview-30]
	_ = x[actChangePreviewLabel-31]
	_ = x[actChangePreviewWindow-32]
	_ = x[actChangePrompt-33]
	_ = x[actChangeQuery-34]
	_ = x[actClearScreen-35]
	_ = x[actClearQuery-36]
	_ = x[actClearSelection-37]
	_ = x[actClose-38]
	_ = x[actDeleteChar-39]
	_ = x[actDeleteCharEof-40]
	_ = x[actEndOfLine-41]
	_ = x[actFatal-42]
	_ = x[actForwardChar-43]
	_ = x[actForwardWord-44]
	_ = x[actForwardSubWord-45]
	_ = x[actKillLine-46]
	_ = x[actKillWord-47]
	_ = x[actKillSubWord-48]
	_ = x[actUnixLineDiscard-49]
	_ = x[actUnixWordRubout-50]
	_ = x[actYank-51]
	_ = x[actBackwardKillWord-52]
	_ = x[actBackwardKillSubWord-53]
	_ = x[actSelectAll-54]
	_ = x[actDeselectAll-55]
	_ = x[actToggle-56]
	_ = x[actToggleSearch-57]
	_ = x[actToggleAll-58]
	_ = x[actToggleDown-59]
	_ = x[actToggleUp-60]
	_ = x[actToggleIn-61]
	_ = x[actToggleOut-62]
	_ = x[actToggleTrack-63]
	_ = x[actToggleTrackCurrent-64]
	_ = x[actToggleHeader-65]
	_ = x[actToggleWrap-66]
	_ = x[actToggleMultiLine-67]
	_ = x[actToggleHscroll-68]
	_ = x[actToggleRaw-69]
	_ = x[actEnableRaw-70]
	_ = x[actDisableRaw-71]
	_ = x[actTrackCurrent-72]
	_ = x[actToggleInput-73]
	_ = x[actHideInput-74]
	_ = x[actShowInput-75]
	_ = x[actUntrackCurrent-76]
	_ = x[actDown-77]
	_ = x[actDownMatch-78]
	_ = x[actUp-79]
	_ = x[actUpMatch-80]
	_ = x[actPageUp-81]
	_ = x[actPageDown-82]
	_ = x[actPosition-83]
	_ = x[actHalfPageUp-84]
	_ = x[actHalfPageDown-85]
	_ = x[actOffsetUp-86]
	_ = x[actOffsetDown-87]
	_ = x[actOffsetMiddle-88]
	_ = x[actJump-89]
	_ = x[actJumpAccept-90]
	_ = x[actPrintQuery-91]
	_ = x[actRefreshPreview-92]
	_ = x[actReplaceQuery-93]
	_ = x[actToggleSort-94]
	_ = x[actShowPreview-95]
	_ = x[actHidePreview-96]
	_ = x[actTogglePreview-97]
	_ = x[actTogglePreviewWrap-98]
	_ = x[actTransform-99]
	_ = x[actTransformBorderLabel-100]
	_ = x[actTransformGhost-101]
	_ = x[actTransformHeader-102]
	_ = x[actTransformFooter-103]
	_ = x[actTransformHeaderLabel-104]
	_ = x[actTransformFooterLabel-105]
	_ = x[actTransformInputLabel-106]
	_ = x[actTransformListLabel-107]
	_ = x[actTransformNth-108]
	_ = x[actTransformPointer-109]
	_ = x[actTransformPreviewLabel-110]
	_ = x[actTransformPrompt-111]
	_ = x[actTransformQuery-112]
	_ = x[actTransformSearch-113]
	_ = x[actTrigger-114]
	_ = x[actBgTransform-115]
	_ = x[actBgTransformBorderLabel-116]
	_ = x[actBgTransformGhost-117]
	_ = x[actBgTransformHeader-118]
	_ = x[actBgTransformFooter-119]
	_ = x[actBgTransformHeaderLabel-120]
	_ = x[actBgTransformFooterLabel-121]
	_ = x[actBgTransformInputLabel-122]
	_ = x[actBgTransformListLabel-123]
	_ = x[actBgTransformNth-124]
	_ = x[actBgTransformPointer-125]
	_ = x[actBgTransformPreviewLabel-126]
	_ = x[actBgTransformPrompt-127]
	_ = x[actBgTransformQuery-128]
	_ = x[actBgTransformSearch-129]
	_ = x[actBgCancel-130]
	_ = x[actSearch-131]
	_ = x[actPreview-132]
	_ = x[actPreviewTop-133]
	_ = x[actPreviewBottom-134]
	_ = x[actPreviewUp-135]
	_ = x[actPreviewDown-136]
	_ = x[actPreviewPageUp-137]
	_ = x[actPreviewPageDown-138]
	_ = x[actPreviewHalfPageUp-139]
	_ = x[actPreviewHalfPageDown-140]
	_ = x[actPrevHistory-141]
	_ = x[actPrevSelected-142]
	_ = x[actPrint-143]
	_ = x[actPut-144]
	_ = x[actNextHistory-145]
	_ = x[actNextSelected-146]
	_ = x[actExecute-147]
	_ = x[actExecuteSilent-148]
	_ = x[actExecuteMulti-149]
	_ = x[actSigStop-150]
	_ = x[actBest-151]
	_ = x[actFirst-152]
	_ = x[actLast-153]
	_ = x[actReload-154]
	_ = x[actReloadSync-155]
	_ = x[actDisableSearch-156]
	_ = x[actEnableSearch-157]
	_ = x[actSelect-158]
	_ = x[actDeselect-159]
	_ = x[actUnbind-160]
	_ = x[actRebind-161]
	_ = x[actToggleBind-162]
	_ = x[actBecome-163]
	_ = x[actShowHeader-164]
	_ = x[actHideHeader-165]
	_ = x[actBell-166]
	_ = x[actExclude-167]
	_ = x[actExcludeMulti-168]
	_ = x[actAsync-169]
}

const _actionType_name = "actIgnoreactStartactClickactInvalidactBracketedPasteBeginactBracketedPasteEndactCharactMouseactBeginningOfLineactAbortactAcceptactAcceptNonEmptyactAcceptOrPrintQueryactBackwardCharactBackwardDeleteCharactBackwardDeleteCharEofactBackwardWordactBackwardSubWordactCancelactChangeBorderLabelactChangeGhostactChangeHeaderactChangeFooteractChangeHeaderLabelactChangeFooterLabelactChangeInputLabelactChangeListLabelactChangeMultiactChangeNthactChangePointeractChangePreviewactChangePreviewLabelactChangePreviewWindowactChangePromptactChangeQueryactClearScreenactClearQueryactClearSelectionactCloseactDeleteCharactDeleteCharEofactEndOfLineactFatalactForwardCharactForwardWordactForwardSubWordactKillLineactKillWordactKillSubWordactUnixLineDiscardactUnixWordRuboutactYankactBackwardKillWordactBackwardKillSubWordactSelectAllactDeselectAllactToggleactToggleSearchactToggleAllactToggleDownactToggleUpactToggleInactToggleOutactToggleTrackactToggleTrackCurrentactToggleHeaderactToggleWrapactToggleMultiLineactToggleHscrollactToggleRawactEnableRawactDisableRawactTrackCurrentactToggleInputactHideInputactShowInputactUntrackCurrentactDownactDownMatchactUpactUpMatchactPageUpactPageDownactPositionactHalfPageUpactHalfPageDownactOffsetUpactOffsetDownactOffsetMiddleactJumpactJumpAcceptactPrintQueryactRefreshPreviewactReplaceQueryactToggleSortactShowPreviewactHidePreviewactTogglePreviewactTogglePreviewWrapactTransformactTransformBorderLabelactTransformGhostactTransformHeaderactTransformFooteractTransformHeaderLabelactTransformFooterLabelactTransformInputLabelactTransformListLabelactTransformNthactTransformPointeractTransformPreviewLabelactTransformPromptactTransformQueryactTransformSearchactTriggeractBgTransformactBgTransformBorderLabelactBgTransformGhostactBgTransformHeaderactBgTransformFooteractBgTransformHeaderLabelactBgTransformFooterLabelactBgTransformInputLabelactBgTransformListLabelactBgTransformNthactBgTransformPointeractBgTransformPreviewLabelactBgTransformPromptactBgTransformQueryactBgTransformSearchactBgCancelactSearchactPreviewactPreviewTopactPreviewBottomactPreviewUpactPreviewDownactPreviewPageUpactPreviewPageDownactPreviewHalfPageUpactPreviewHalfPageDownactPrevHistoryactPrevSelectedactPrintactPutactNextHistoryactNextSelectedactExecuteactExecuteSilentactExecuteMultiactSigStopactBestactFirstactLastactReloadactReloadSyncactDisableSearchactEnableSearchactSelectactDeselectactUnbindactRebindactToggleBindactBecomeactShowHeaderactHideHeaderactBellactExcludeactExcludeMultiactAsync"

var _actionType_index = [...]uint16{0, 9, 17, 25, 35, 57, 77, 84, 92, 110, 118, 127, 144, 165, 180, 201, 225, 240, 258, 267, 287, 301, 316, 331, 351, 371, 390, 408, 422, 434, 450, 466, 487, 509, 524, 538, 552, 565, 582, 590, 603, 619, 631, 639, 653, 667, 684, 695, 706, 720, 738, 755, 762, 781, 803, 815, 829, 838, 853, 865, 878, 889, 900, 912, 926, 947, 962, 975, 993, 1009, 1021, 1033, 1046, 1061, 1075, 1087, 1099, 1116, 1123, 1135, 1140, 1150, 1159, 1170, 1181, 1194, 1209, 1220, 1233, 1248, 1255, 1268, 1281, 1298, 1313, 1326, 1340, 1354, 1370, 1390, 1402, 1425, 1442, 1460, 1478, 1501, 1524, 1546, 1567, 1582, 1601, 1625, 1643, 1660, 1678, 1688, 1702, 1727, 1746, 1766, 1786, 1811, 1836, 1860, 1883, 1900, 1921, 1947, 1967, 1986, 2006, 2017, 2026, 2036, 2049, 2065, 2077, 2091, 2107, 2125, 2145, 2167, 2181, 2196, 2204, 2210, 2224, 2239, 2249, 2265, 2280, 2290, 2297, 2305, 2312, 2321, 2334, 2350, 2365, 2374, 2385, 2394, 2403, 2416, 2425, 2438, 2451, 2458, 2468, 2483, 2491}

func (i actionType) String() string {
	if i < 0 || i >= actionType(len(_actionType_index)-1) {
		return "actionType(" + strconv.FormatInt(int64(i), 10) + ")"
	}
	return _actionType_name[_actionType_index[i]:_actionType_index[i+1]]
}
